/********************************************************************
Program:        exportData.sas
Author:         Bill McNeill - SAS Institute
Date:           February 28, 2013
Requirement(s): * Base SAS 9.3 or better (except JSON procedure)
                * Base SAS 9.4 or better (using JSON procedure)
Purpose:        Export SAS data sets to files in XML and JSON format.
Called From:    webDataDemo.sas
Results:        * weatherOut.xml
                * weatherOut.json
                * weatherOut2.json
********************************************************************/
%put ">>>>>>>>>> Entering exportData.sas";
/* EXPORT XML FORMAT */
/* Define a libref to export to an output file the daily weather data
   in XML format. */
libname wthrOut xmlv2 "output\weatherOut.xml";
data wthrOut.confWeather;
  set personal.weather;
run;
/* Display the output file containing the daily weather data in XML 
   format. */
%fileecho("output\weatherOut.xml");
/* Compare the output file to the data in the data set. */
proc print data=personal.weather; run;

/* EXPORT JSON FORMAT */
/* Export the same weather data as above in JSON format. As noted, 
   the following steps require SAS 9.4 to run. */
option source2;
/* Requires SAS 9.4! */
proc json out="output\weatherOut.json" pretty nosastags;
  export personal.weather;
run;
/* Display the JSON export file in the SAS log. */
%fileecho("output\weatherOut.json");

/* Show an example of how to use free-form JSON output and SAS DATA
   step options from the JSON procedure. */
proc json out="output\weatherOut2.json" pretty nosastags;
  write value "Daily Weather";
    write open array;
    write value "Sunday";
      export personal.weather(where=(date="28APR2013"d));
    write value "Monday";
      export personal.weather(where=(date="29APR2013"d));
    write value "Tuesday";
      export personal.weather(where=(date="30APR2013"d));
    write value "Wednesday";
      export personal.weather(where=(date="01MAY2013"d));
    write close;
run;
%fileecho("output\weatherOut2.json");
option nosource2;

%put "<<<<<<<<<< Exiting exportData.sas";

