/********************************************************************
Program:        personalSchedule.sas
Author:         Bill McNeill - SAS Institute
Date:           February 28, 2013
Requirement(s): Base SAS
Purpose:        Create various data sets with personal schedule 
                information. These data sets will be used to enhance 
                the general SAS Global Forum schedule created earlier.
Called From:    webDataDemo.sas
Results:        * WORK.FULLSORTEDSCHEDULE
                * PERSONAL.WEATHER
********************************************************************/
%put ">>>>>>>>>> Entering personalSchedule.sas";
/*------------------------------------------------------------------
Name:       declareInformats
Purpose:    Common informat definitions used by the data sets in
            this program.
------------------------------------------------------------------*/
%macro declareInformats();
informat  activity       $200.
          startTimeValue time5.
		  stopTimeValue  time5.
          eventDate      mmddyy10.;
%mend  declareInformats;

/*------------------------------------------------------------------
Name:       declareFormats
Purpose:    Common format definitions used by the data sets in
            this program.
------------------------------------------------------------------*/
%macro declareFormats();
format  activity       $200.
        startTimeValue timeampm8.
		stopTimeValue  timeampm8.
        eventDate      WEEKDATE29.;
%mend  declareFormats;

/* Create a data set with the date and time of my paper presentation. 
   This is a required activity.                                       */
data work.required;
  %declareInformats();
  %declareFormats();
  activityType="Required";
  infile datalines truncover;
  input eventDate startTimeValue stopTimeValue activity 24-224;
  datalines;
04/29/2013 15:00 15:50 Paper Presentation
04/30/2013 14:00 14:30 JSON Super Demo
04/29/2013 11:30 12:00 Customer Meeting
04/28/2013 16:00 18:15 Demo Duty
04/29/2013 10:00 11:00 Demo Duty
04/30/2013 13:00 14:00 Demo Duty
04/30/2013 16:00 17:00 Demo Duty
;;;;
run;

/*
proc print data=work.required; run;
*/



/* Create a data set with the dates and times of activities I should 
   attend if at all possible. These are recommended activities.      
   Note that these activities are currently in the schedule as GENERAL
   activities.                                                         */
/*
data work.recommended;
  %declareInformats();
  %declareFormats();
  activityType="Recommended";
  infile datalines truncover;
  input eventDate startTimeValue stopTimeValue;
  datalines;
04/28/2013 16:00 18:15 
04/28/2013 19:00 20:30 
04/28/2013 20:30 23:00 
04/29/2013 08:00 10:00 
04/29/2013 18:00 19:30 
04/30/2013 21:00 00:00 
;;;;
run;


proc print data=work.recommended; run;
*/

/* Brute force through the GENERAL schedule data and find the 
   activities that it is recommended that I attend. When the activity
   is found, change the activityType value to RECOMMENDED.            */
data work.scheduleUpdate(drop=activityName);
  set work.schedule;
  activityName=compress(activity);
  if activityName eq compress("Opening Session")                              then activityType="Recommended";
  if activityName eq compress("Kick Back Party")                              then activityType="Recommended";
  if activityName eq compress("Mixer Hosted by SAS Customer Loyalty")         then activityType="Recommended";
  if activityName eq compress("Get-Acquainted Reception")                     then activityType="Recommended";
  if activityName eq compress('Technology Connection & Keynote Presentation') then activityType="Recommended";
run;

/*
proc print data=work.scheduleUpdate; run;
*/


/* Create a data set with the dates and times of activities I would 
   like to attend if possible. These are desired activities.        */
data work.otherEvents;
  %declareInformats();
  %declareFormats();
  activityType="Desired";
  infile datalines truncover;
  input eventDate startTimeValue stopTimeValue activity 24-224;
  datalines4;
04/29/2013 11:30 11:50 021-2013 The Hash-of-Hashes as a "Russian Doll" Structure: An Example with XML Creation
04/30/2013 09:00 09:20 121-2013 Reading Data from Microsoft Word Documents: It's Easier Than You Might Think
04/30/2013 11:00 11:50 124-2013 The SAS Programmer's Guide to XML and Web Services
04/29/2013 14:00 15:30 201-2013 A Practical Approach to Creating Define.XML by Using SDTM Specifications and Excel functions
04/29/2013 14:00 15:30 234-2013 A Preventive Approach for Automatic Checking of CDISC ADaM Metadata to Detect Noncompliance
04/29/2013 15:00 15:10 296-2013 Efficient Extraction of JSON Information in SAS Using the SCANOVER Function
05/01/2013 09:45 09:55 342-2013 %GetReviews: A SAS Macro to Retrieve User Reviews in JSON Format from Review Websites and Create SAS Data Sets
;;;;
run;

/*
proc print data=work.otherEvents; run;
*/

/* Combine all the data sets created here along with the updated SAS
   Global Forum schedule created earlier to form my full schedule.    */
data work.fullSchedule;
  set work.scheduleUpdate work.otherEvents work.required;
run;

/*
proc print data=work.fullSchedule; run;
*/

/* Sort the full schedule by date and time. */
proc sort data=work.fullSchedule out=work.fullSortedSchedule;
  by eventDate startTimeValue stopTimeValue;
run;

title "Full Schedule";
proc print data=work.fullSortedSchedule; run;

/* Current weather data set set to SGF dates. */
libname personal base 'data/';

%put "<<<<<<<<<< Exiting personalSchedule.sas";
