/******************************************************************** 
Program:        webDataDemo.sas
Author:         Bill McNeill - SAS Institute
Date:           February 28, 2013
Requirement(s): * Base SAS 9.3 or later
                * Base SAS 9.3M2 or later (XMLV2 LIBNAME AUTOMAP= option)
                * Base SAS 9.4 (JSON procedure)
                * Internet access
Called From:    Nothing; top level program.
Purpose:        Main program to demonstrate various methods of obtaining 
                data from internet sites for a SAS program and making 
                SAS data available from the internet.
********************************************************************/
option nosource;
%put ">>>>>>>>>> Entering webDataDemo.sas";
/* Demonstrate methods to create SAS data sets from HTML tables. */
%include "sasuser\getHtml.sas";

/* Demonstrate methods to create SAS data sets via PROC HTTP. This step
   will supply directions from the hotel to the conference in 2 data sets:
   WORK.DIRSUM and WORK.DIRSPEC. */
%include "sasuser\getHttpXml.sas";

/* Demonstrate a method to create SAS data sets via PROC SOAP. This step
   will supply weather forecasts for each day of the conference in 2
   data sets: WORK.WEATHER and WORK.WEATHEROVERHEAD. */
%include "sasuser\getSoapXml.sas";

/* Based on the HTML table, a general SAS Global Forum schedule was 
   created. Now enhance that schedule with personal activities and 
   save in WORK.FULLSORTEDSCHEDULE. */
%include "sasuser\personalSchedule.sas";

/* Demonstrate various methods for surfacing the collected schedule data... */
%include "sasuser\showCollectedData.sas";
/* ...HTML output file... */
%include "sasuser\displaySchedule.sas";
/* ...XML and JSON output files. */
%include "sasuser\exportData.sas";

%put "<<<<<<<<<< Exiting webDataDemo.sas";
